==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/openShop/CreateRequest.java <==
package eleme.openapi.sdk.api.entity.openShop;


import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;

public class CreateRequest{

    /**
     * 店铺名称
     */
    private String storeName;
    public String getStoreName() {
        return storeName;
    }
    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    
    /**
     * 商户id
     */
    private Long merchantId;
    public Long getMerchantId() {
        return merchantId;
    }
    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
    
    /**
     * 来源(开发前，需要提前约定)
     */
    private String origin;
    public String getOrigin() {
        return origin;
    }
    public void setOrigin(String origin) {
        this.origin = origin;
    }
    
    /**
     * 地址信息
     */
    private UnifiedAddressInfo addressInfo;
    public UnifiedAddressInfo getAddressInfo() {
        return addressInfo;
    }
    public void setAddressInfo(UnifiedAddressInfo addressInfo) {
        this.addressInfo = addressInfo;
    }
    
    /**
     * 联系人信息
     */
    private ContactInfo contactInfo;
    public ContactInfo getContactInfo() {
        return contactInfo;
    }
    public void setContactInfo(ContactInfo contactInfo) {
        this.contactInfo = contactInfo;
    }
    
    /**
     * 执照信息
     */
    private List<UnifiedShopCertificationInfo> certificationInfos;
    public List<UnifiedShopCertificationInfo> getCertificationInfos() {
        return certificationInfos;
    }
    public void setCertificationInfos(List<UnifiedShopCertificationInfo> certificationInfos) {
        this.certificationInfos = certificationInfos;
    }
    
    /**
     * 品类信息
     */
    private List<CategoryInfo> categories;
    public List<CategoryInfo> getCategories() {
        return categories;
    }
    public void setCategories(List<CategoryInfo> categories) {
        this.categories = categories;
    }
    
    /**
     * 图片信息
     */
    private List<ApplyImageInfo> images;
    public List<ApplyImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ApplyImageInfo> images) {
        this.images = images;
    }
    
    /**
     * 客户端信息
     */
    private ClientInfo clientInfo;
    public ClientInfo getClientInfo() {
        return clientInfo;
    }
    public void setClientInfo(ClientInfo clientInfo) {
        this.clientInfo = clientInfo;
    }
    
}

==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/openShop/CreateRequest.java <==
package eleme.openapi.sdk.api.entity.openShop;

import eleme.openapi.sdk.api.enumeration.openShop.*;
import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class CreateRequest{

    /**
     * 店铺名称
     */
    private String storeName;
    public String getStoreName() {
        return storeName;
    }
    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    
    /**
     * 商户id
     */
    private Long merchantId;
    public Long getMerchantId() {
        return merchantId;
    }
    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
    
    /**
     * 来源(开发前，需要提前约定)
     */
    private String origin;
    public String getOrigin() {
        return origin;
    }
    public void setOrigin(String origin) {
        this.origin = origin;
    }
    
    /**
     * 地址信息
     */
    private UnifiedAddressInfo addressInfo;
    public UnifiedAddressInfo getAddressInfo() {
        return addressInfo;
    }
    public void setAddressInfo(UnifiedAddressInfo addressInfo) {
        this.addressInfo = addressInfo;
    }
    
    /**
     * 联系人信息
     */
    private ContactInfo contactInfo;
    public ContactInfo getContactInfo() {
        return contactInfo;
    }
    public void setContactInfo(ContactInfo contactInfo) {
        this.contactInfo = contactInfo;
    }
    
    /**
     * 执照信息
     */
    private List<UnifiedShopCertificationInfo> certificationInfos;
    public List<UnifiedShopCertificationInfo> getCertificationInfos() {
        return certificationInfos;
    }
    public void setCertificationInfos(List<UnifiedShopCertificationInfo> certificationInfos) {
        this.certificationInfos = certificationInfos;
    }
    
    /**
     * 品类信息
     */
    private List<CategoryInfo> categories;
    public List<CategoryInfo> getCategories() {
        return categories;
    }
    public void setCategories(List<CategoryInfo> categories) {
        this.categories = categories;
    }
    
    /**
     * 图片信息
     */
    private List<ApplyImageInfo> images;
    public List<ApplyImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ApplyImageInfo> images) {
        this.images = images;
    }
    
    /**
     * 客户端信息
     */
    private ClientInfo clientInfo;
    public ClientInfo getClientInfo() {
        return clientInfo;
    }
    public void setClientInfo(ClientInfo clientInfo) {
        this.clientInfo = clientInfo;
    }
    
}
